

Anchor annotator documentation
==============================

.. warning::

   Anchor is in early early alpha, there are many rough edges and krakens abound.  Please ensure you are using version control with something like git for your files in case anything goes destructively wrong.  Please refer to :ref:`known_issues` if you encounter anything weird, but otherwise you can file a `GitHub issue <https://github.com/MontrealCorpusTools/Anchor-annotator/issues>`_ via the :fa:`bug;sd-text-secondary` button in Anchor.

.. grid:: 2

    .. grid-item-card:: Getting started
       :text-align: center

       :fas:`running;fa-6x i-navigation`

       ^^^

       Install Anchor and its dependencies

       +++

       .. button-ref:: getting_started
          :expand:
          :color: primary

          Install Anchor

    .. grid-item-card:: First steps
       :text-align: center

       :fas:`terminal;fa-6x i-navigation`

       ^^^

       Have a particular use case for Anchor?

       Check out the first steps tutorials.

       +++

       .. button-ref:: first_steps
          :expand:
          :color: primary

          First steps

    .. grid-item-card:: User guide
       :text-align: center

       :fas:`book-open;fa-6x i-navigation`

       ^^^

       The User Guide gives more details on the various functions in Anchor.

       +++

       .. button-ref:: user_guide
          :expand:
          :color: primary

          User guide

    .. grid-item-card:: API reference
       :text-align: center

       :fas:`file-code;fa-6x i-navigation`

       ^^^

       The API guide contains documentation for each aspect of Anchor.

       +++

       .. button-ref:: anchor_api
          :expand:
          :color: primary

          Reference guide

.. toctree::
   :hidden:

   Getting started <getting_started.rst>
   User guide <user_guide/index.rst>
   API reference <reference/index.rst>
   Changelog <changelog/index.rst>

Attribution
===========

The Anchor Annotator uses icons from `FontAwesome <https://fontawesome.com/>`_.
